==> com.liferay.site.cmp.site.initializer-1.0.1-sources.jar: com/liferay/site/cmp/site/initializer/internal/frontend/data/set/view/table/ProjectSectionTableFDSView.java <==
/**
 * SPDX-FileCopyrightText: (c) 2026 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.site.cmp.site.initializer.internal.frontend.data.set.view.table;

import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.table.BaseTableFDSView;
import com.liferay.frontend.data.set.view.table.DateFDSTableSchemaField;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilder;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilderFactory;
import com.liferay.portal.kernel.json.JSONUtil;
import com.liferay.site.cmp.site.initializer.internal.constants.CMPSiteInitializerFDSNames;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Gabriel Albuquerque
 */
@Component(
	property = "frontend.data.set.name=" + CMPSiteInitializerFDSNames.CMP_PROJECT,
	service = FDSView.class
)
public class ProjectSectionTableFDSView extends BaseTableFDSView {

	@Override
	public FDSTableSchema getFDSTableSchema(Locale locale) {
		FDSTableSchemaBuilder fdsTableSchemaBuilder =
			_fdsTableSchemaBuilderFactory.create();

		return fdsTableSchemaBuilder.add(
			"embedded.title", "title",
			fdsTableSchemaField -> fdsTableSchemaField.setActionId(
				"actionLink"
			).setContentRenderer(
				"simpleActionLinkTableCellRenderer"
			)
		).add(
			_getDateFDSTableSchemaField("embedded.dueDate", "due-date")
		).add(
			"embedded.completionRate", "completion-rate",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"progressBarTableCellRenderer")
		).add(
			"embedded.r_userToCMPProjectManager_userERC", "manager",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"userRelationshipTableCellRenderer")
		).add(
			"embedded.r_userToCMPProjectSponsor_userERC", "sponsor",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"userRelationshipTableCellRenderer")
		).add(
			"embedded.state", "state",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"stateTableCellRenderer")
		).build();
	}

	private DateFDSTableSchemaField _getDateFDSTableSchemaField(
		String fieldName, String label) {

		DateFDSTableSchemaField dateFDSTableSchemaField =
			new DateFDSTableSchemaField();

		dateFDSTableSchemaField.setFieldName(fieldName);
		dateFDSTableSchemaField.setFormat(
			JSONUtil.put(
				"day", "numeric"
			).put(
				"month", "numeric"
			).put(
				"year", "numeric"
			));
		dateFDSTableSchemaField.setLabel(
			label
		).setLocalizeLabel(
			true
		);

		return dateFDSTableSchemaField;
	}

	@Reference
	private FDSTableSchemaBuilderFactory _fdsTableSchemaBuilderFactory;

}

==> com.liferay.site.cmp.site.initializer-1.0.2-sources.jar: com/liferay/site/cmp/site/initializer/internal/frontend/data/set/view/table/ProjectSectionTableFDSView.java <==
/**
 * SPDX-FileCopyrightText: (c) 2026 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.site.cmp.site.initializer.internal.frontend.data.set.view.table;

import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.table.BaseTableFDSView;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilder;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilderFactory;
import com.liferay.site.cmp.site.initializer.internal.constants.CMPSiteInitializerFDSNames;
import com.liferay.site.cmp.site.initializer.internal.util.FDSViewUtil;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Gabriel Albuquerque
 */
@Component(
	property = "frontend.data.set.name=" + CMPSiteInitializerFDSNames.CMP_PROJECT,
	service = FDSView.class
)
public class ProjectSectionTableFDSView extends BaseTableFDSView {

	@Override
	public FDSTableSchema getFDSTableSchema(Locale locale) {
		FDSTableSchemaBuilder fdsTableSchemaBuilder =
			_fdsTableSchemaBuilderFactory.create();

		return fdsTableSchemaBuilder.add(
			"embedded.title", "title",
			fdsTableSchemaField -> fdsTableSchemaField.setActionId(
				"actionLink"
			).setContentRenderer(
				"simpleActionLinkTableCellRenderer"
			)
		).add(
			FDSViewUtil.getDateFDSTableSchemaField(
				"embedded.dueDate", "due-date")
		).add(
			"embedded.completionRate", "completion-rate",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"progressBarTableCellRenderer")
		).add(
			"embedded.r_userToCMPProjectManager_userERC", "manager",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"userRelationshipTableCellRenderer")
		).add(
			"embedded.r_userToCMPProjectSponsor_userERC", "sponsor",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"userRelationshipTableCellRenderer")
		).add(
			"embedded.state", "state",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"stateTableCellRenderer")
		).build();
	}

	@Reference
	private FDSTableSchemaBuilderFactory _fdsTableSchemaBuilderFactory;

}
